{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Samtools-index",
            "doc": "Samtools is a suite of programs for interacting with high-throughput sequencing data",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.in_bam)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.10--h9402c20_2",
                    "id": "#samtools-docker.yml"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "package": "samtools",
                            "version": [
                                "1.10"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/samtools"
                            ]
                        }
                    ],
                    "id": "#samtools-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-index.cwl/in_bam"
                },
                {
                    "type": "string",
                    "id": "#samtools-index.cwl/out_bai"
                }
            ],
            "baseCommand": [
                "samtools",
                "index",
                "-b"
            ],
            "id": "#samtools-index.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bai"
                    },
                    "id": "#samtools-index.cwl/out_sam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Samtools-sort",
            "doc": "Samtools is a suite of programs for interacting with high-throughput sequencing data",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": "$(inputs.threads)",
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "$import": "#samtools-docker.yml"
                },
                {
                    "$import": "#samtools-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#samtools-sort.cwl/in_bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-n",
                        "position": 1
                    },
                    "id": "#samtools-sort.cwl/n"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-o"
                    },
                    "id": "#samtools-sort.cwl/out_bam"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--threads",
                        "position": 1
                    },
                    "id": "#samtools-sort.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_bam)"
                    },
                    "id": "#samtools-sort.cwl/out_sam"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "id": "#samtools-sort.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Samtools-stats",
            "doc": "Samtools is a suite of programs for interacting with high-throughput sequencing data",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "$import": "#samtools-docker.yml"
                },
                {
                    "$import": "#samtools-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "id": "#samtools-stats.cwl/in_bam",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#samtools-stats.cwl/stdout",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#samtools-stats.cwl/out_stdout",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.stdout)"
                    }
                }
            ],
            "stdout": "$(inputs.stdout)",
            "baseCommand": [
                "samtools",
                "stats"
            ],
            "id": "#samtools-stats.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "Spliced Transcripts Alignment to a Reference",
            "label": "STAR",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": "$(inputs.threads)",
                    "ramMax": "${\n    return inputs.limitGenomeGenerateRAM ? inputs.limitGenomeGenerateRAM : 32000\n}\n",
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/star:2.7.5a--0",
                    "id": "#star-docker.yml"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "package": "star",
                            "version": [
                                "2.7.5a"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/star"
                            ]
                        }
                    ],
                    "id": "#star-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "id": "#star.cwl/alignEndsType",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignEndsType"
                    },
                    "doc": "Local\nstring: type of read ends alignment\nLocal           ... standard local alignment with soft-clipping allowed\nEndToEnd        ... force end-to-end read alignment, do not soft-clip\nExtend5pOfRead1 ... fully extend only the 5p of the read1, all other ends: local alignment\n"
                },
                {
                    "id": "#star.cwl/alignSJDBoverhangMin",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignSJDBoverhangMin"
                    },
                    "doc": "3\nint>0: minimum overhang (i.e. block size) for annotated (sjdb) spliced alignments\n"
                },
                {
                    "id": "#star.cwl/alignSJoverhangMin",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignSJoverhangMin"
                    },
                    "doc": "15\nint>0: minimum overhang (i.e. block size) for spliced alignments\n"
                },
                {
                    "id": "#star.cwl/genomeDir",
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--genomeDir"
                    }
                },
                {
                    "id": "#star.cwl/limitGenomeGenerateRAM",
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitGenomeGenerateRAM",
                        "valueFrom": "${\n    return parseInt(self, 10) * 1000000;\n }\n"
                    },
                    "doc": "31000000000\nint>0: maximum available RAM (Megabytes) for genome generation\n"
                },
                {
                    "id": "#star.cwl/limitOutSJcollapsed",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitOutSJcollapsed"
                    },
                    "doc": "1000000\nint>0: max number of collapsed junctions\n"
                },
                {
                    "id": "#star.cwl/limitSjdbInsertNsj",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitSjdbInsertNsj"
                    },
                    "doc": "1000000\nint>=0: maximum number of junction to be inserted to the genome on the fly at the mapping stage, including those from annotations and those detected in the 1st step of the 2-pass run"
                },
                {
                    "id": "#star.cwl/outFileNamePrefix",
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--outFileNamePrefix"
                    },
                    "doc": "string: output files name prefix (including full or relative path). Can\nonly be defined on the command line.\n"
                },
                {
                    "id": "#star.cwl/outFilterMatchNminOverLread",
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMatchNminOverLread"
                    },
                    "doc": "0.0\nfloat: outFilterMatchNmin normalized to read length (sum of mates' lengths for paired-end reads)\n"
                },
                {
                    "id": "#star.cwl/outFilterMismatchNmax",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMismatchNmax"
                    },
                    "doc": "33\nint: alignment will be output only if it has fewer mismatches than this value\n"
                },
                {
                    "id": "#star.cwl/outFilterMismatchNoverLmax",
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMismatchNoverLmax"
                    },
                    "doc": "0.3\nint: alignment will be output only if its ratio of mismatches to *mapped* length is less than this value\n"
                },
                {
                    "id": "#star.cwl/outFilterMultimapNmax",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMultimapNmax"
                    },
                    "doc": "100\nint: read alignments will be output only if the read maps fewer than this value, otherwise no alignments will be output\n"
                },
                {
                    "id": "#star.cwl/outFilterScoreMinOverLread",
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterScoreMinOverLread"
                    },
                    "doc": "0.3\nfloat: outFilterScoreMin normalized to read length (sum of mates' lengths for paired-end reads)\n"
                },
                {
                    "id": "#star.cwl/outFilterType",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterType"
                    },
                    "doc": "Normal\nstring: type of filtering\nNormal  ... standard filtering using only current alignment\nBySJout ... keep only those reads that contain junctions that passed filtering into SJ.out.tab\n"
                },
                {
                    "id": "#star.cwl/outSAMtype",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMtype",
                        "shellQuote": false
                    }
                },
                {
                    "id": "#star.cwl/outSAMunmapped",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMunmapped"
                    }
                },
                {
                    "id": "#star.cwl/outStd",
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--outStd"
                    }
                },
                {
                    "id": "#star.cwl/readFilesCommand",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--readFilesCommand"
                    }
                },
                {
                    "id": "#star.cwl/reads",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--readFilesIn"
                    },
                    "doc": "string(s): paths to files that contain input read1 (and, if needed,  read2)\n"
                },
                {
                    "id": "#star.cwl/seedSearchStartLmax",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedSearchStartLmax"
                    },
                    "doc": "12\nint>0: defines the search start point through the read - the read is split into pieces no longer than this value\n"
                },
                {
                    "id": "#star.cwl/threads",
                    "type": "int",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--runThreadN"
                    }
                },
                {
                    "id": "#star.cwl/twopassMode",
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--twopassMode"
                    }
                },
                {
                    "id": "#star.cwl/winAnchorMultimapNmax",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--winAnchorMultimapNmax"
                    },
                    "doc": "50\nint>0: max number of loci anchors are allowed to map to\n"
                },
                {
                    "id": "#star.cwl/quantMode",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--quantMode"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#star.cwl/aligned",
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  var p = inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Aligned.out.bam\";\n}\n"
                    },
                    "secondaryFiles": [
                        "${\n   var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n   return [\n     {\"path\": p+\"Log.final.out\", \"class\":\"File\"},\n     {\"path\": p+\"SJ.out.tab\", \"class\":\"File\"},\n     {\"path\": p+\"Log.out\", \"class\":\"File\"}\n   ];\n}\n"
                    ]
                },
                {
                    "id": "#star.cwl/bamRemDups",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.bamRemoveDuplicatesType != \"UniqueIdentical\")\n    return null;\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Processed.out.bam\";\n}\n"
                    }
                },
                {
                    "id": "#star.cwl/mappingstats",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "${\n  var p = inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Log.final.out\";\n}\n"
                    }
                },
                {
                    "id": "#star.cwl/readspergene",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"ReadsPerGene.out.tab\";\n}\n"
                    }
                },
                {
                    "id": "#star.cwl/transcriptomesam",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Aligned.toTranscriptome.out.bam\";\n}\n"
                    }
                }
            ],
            "baseCommand": [
                "STAR"
            ],
            "id": "#star.cwl"
        },
        {
            "class": "Workflow",
            "doc": "This workflow aligns the fastq files using STAR for paired-end samples",
            "label": "STAR-Alignment-PE",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#main/genomeDir"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/ramMaxSTAR"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/reads"
                },
                {
                    "type": "int",
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/bam_index/out_sam",
                    "type": "File",
                    "id": "#main/indexed_bam"
                },
                {
                    "outputSource": "#main/alignment/mappingstats",
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/mappingstats"
                },
                {
                    "outputSource": "#main/alignment/readspergene",
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/readspergene"
                },
                {
                    "outputSource": "#main/bam_sort/out_sam",
                    "type": "File",
                    "id": "#main/sorted_bam"
                },
                {
                    "outputSource": "#main/alignment/mappingstats",
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/star_stats"
                },
                {
                    "outputSource": "#main/bam_stats/out_stdout",
                    "type": "File",
                    "id": "#main/stats_bam"
                }
            ],
            "steps": [
                {
                    "run": "#star.cwl",
                    "label": "STAR",
                    "in": [
                        {
                            "default": "Local",
                            "id": "#main/alignment/alignEndsType"
                        },
                        {
                            "default": 1,
                            "id": "#main/alignment/alignSJDBoverhangMin"
                        },
                        {
                            "default": 15,
                            "id": "#main/alignment/alignSJoverhangMin"
                        },
                        {
                            "source": "#main/genomeDir",
                            "id": "#main/alignment/genomeDir"
                        },
                        {
                            "source": "#main/ramMaxSTAR",
                            "id": "#main/alignment/limitGenomeGenerateRAM"
                        },
                        {
                            "default": 1000000,
                            "id": "#main/alignment/limitOutSJcollapsed"
                        },
                        {
                            "default": 1000000,
                            "id": "#main/alignment/limitSjdbInsertNsj"
                        },
                        {
                            "valueFrom": "${\n  var nameroot = inputs.reads[0].nameroot;\n  if (nameroot.endsWith(\".fastq\")){\n     nameroot = nameroot.replace(\".fastq\", \"\")\n  }\n  if (nameroot.endsWith(\"_1\") || nameroot.endsWith(\"_2\")){\n     nameroot = nameroot.slice(0, -2);\n  }\n  return nameroot;\n}\n",
                            "id": "#main/alignment/outFileNamePrefix"
                        },
                        {
                            "default": 0,
                            "id": "#main/alignment/outFilterMatchNminOverLread"
                        },
                        {
                            "default": 33,
                            "id": "#main/alignment/outFilterMismatchNmax"
                        },
                        {
                            "default": 0.3,
                            "id": "#main/alignment/outFilterMismatchNoverLmax"
                        },
                        {
                            "default": 100,
                            "id": "#main/alignment/outFilterMultimapNmax"
                        },
                        {
                            "default": 0.3,
                            "id": "#main/alignment/outFilterScoreMinOverLread"
                        },
                        {
                            "default": "BySJout",
                            "id": "#main/alignment/outFilterType"
                        },
                        {
                            "default": [
                                "BAM",
                                "Unsorted"
                            ],
                            "id": "#main/alignment/outSAMtype"
                        },
                        {
                            "default": "Within",
                            "id": "#main/alignment/outSAMunmapped"
                        },
                        {
                            "default": "Log",
                            "id": "#main/alignment/outStd"
                        },
                        {
                            "default": "GeneCounts",
                            "id": "#main/alignment/quantMode"
                        },
                        {
                            "default": "zcat",
                            "id": "#main/alignment/readFilesCommand"
                        },
                        {
                            "source": "#main/reads",
                            "id": "#main/alignment/reads"
                        },
                        {
                            "default": 12,
                            "id": "#main/alignment/seedSearchStartLmax"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/alignment/threads"
                        },
                        {
                            "default": "Basic",
                            "id": "#main/alignment/twopassMode"
                        },
                        {
                            "default": 50,
                            "id": "#main/alignment/winAnchorMultimapNmax"
                        }
                    ],
                    "out": [
                        "#main/alignment/aligned",
                        "#main/alignment/bamRemDups",
                        "#main/alignment/mappingstats",
                        "#main/alignment/readspergene",
                        "#main/alignment/transcriptomesam"
                    ],
                    "id": "#main/alignment"
                },
                {
                    "run": "#samtools-index.cwl",
                    "label": "Samtools-index",
                    "in": [
                        {
                            "source": "#main/bam_sort/out_sam",
                            "id": "#main/bam_index/in_bam"
                        },
                        {
                            "valueFrom": "${ return inputs.in_bam.basename + \".bai\";}",
                            "id": "#main/bam_index/out_bai"
                        }
                    ],
                    "out": [
                        "#main/bam_index/out_sam"
                    ],
                    "id": "#main/bam_index"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "label": "Samtools-sort",
                    "in": [
                        {
                            "source": "#main/alignment/aligned",
                            "id": "#main/bam_sort/in_bam"
                        },
                        {
                            "valueFrom": "${ return inputs.in_bam.nameroot.replace('Aligned.out', '') + \"_sorted.bam\";}",
                            "id": "#main/bam_sort/out_bam"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/bam_sort/threads"
                        }
                    ],
                    "out": [
                        "#main/bam_sort/out_sam"
                    ],
                    "id": "#main/bam_sort"
                },
                {
                    "run": "#samtools-stats.cwl",
                    "label": "Samtools-stats",
                    "in": [
                        {
                            "source": "#main/alignment/aligned",
                            "id": "#main/bam_stats/in_bam"
                        },
                        {
                            "valueFrom": "${ return inputs.in_bam.nameroot + \".stats\";}",
                            "id": "#main/bam_stats/stdout"
                        }
                    ],
                    "out": [
                        "#main/bam_stats/out_stdout"
                    ],
                    "id": "#main/bam_stats"
                }
            ],
            "id": "#main",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
